@@ -19,14 +19,14 @@ class BaseTuringMachine:
         states: Set[str],
         input_alphabet: Set[str],
         acc_states: Set[str],
-        rej_states: Set[str] = set(),
+        rej_states: Set[str],
         initial_state: str = "init",
         start_symbol: str = ">",
     ) -> None:
-        self.states = states
-        self.input_alphabet = input_alphabet
-        self.acc_states = acc_states
-        self.rej_states = rej_states
+        self.states = states or set()
+        self.input_alphabet = input_alphabet or set()
+        self.acc_states = acc_states or set()
+        self.rej_states = rej_states or set()
         self.initial_state = initial_state
         self.start_symbol = start_symbol
 
